@@ -136,9 +136,9 @@ from .util import is_iterable, is_mobile, is_tablet, is_browser, is_bot, browser
     gather_errors, gen_token, html_to_text, camel_to_underscore, camel_to_readable, underscore_to_readable, quote,\
     unquote, unescape, split_unescape, call_safe, base_name, base_name_m, is_content_type, parse_content_type, parse_cookie,\
     parse_multipart, decode_params, load_form, check_login, check_token, check_tokens, ensure_login, get_tokens_m,\
-    to_tokens_m, dict_merge, cached, private, ensure, delayed, route, error_handler, exception_handler, before_request,\
-    after_request, is_detached, sanitize, verify, verify_equal, verify_not_equal, execute, ctx_locale, ctx_request,\
-    FileTuple, BaseThread, JSONEncoder
+    to_tokens_m, dict_merge, deprecated, cached, private, ensure, delayed, route, error_handler, exception_handler,\
+    before_request, after_request, is_detached, sanitize, verify, verify_equal, verify_not_equal, verify_many, execute,\
+    ctx_locale, ctx_request, FileTuple, BaseThread, JSONEncoder
 from .validation import validate, validate_b, validate_e, safe, eq, gt, gte, lt, lte, not_null, not_empty, not_false,\
     is_in, is_upper, is_lower, is_simple, is_email, is_url, is_regex, field_eq, field_gt, field_gte, field_lt,\
     field_lte, string_gt, string_lt, string_eq, equals, not_past, not_duplicate, all_different, no_self
