@@ -127,6 +127,9 @@ class UtilTest(unittest.TestCase):
         result = appier.is_browser("netius/1.1.10")
         self.assertEqual(result, False)
 
+        result = appier.is_browser("netius/1.1b")
+        self.assertEqual(result, False)
+
         result = appier.is_browser("")
         self.assertEqual(result, False)
 
@@ -161,6 +164,9 @@ class UtilTest(unittest.TestCase):
         result = appier.is_bot("netius/1.1.10")
         self.assertEqual(result, False)
 
+        result = appier.is_bot("netius/1.1b")
+        self.assertEqual(result, False)
+
         result = appier.is_bot("")
         self.assertEqual(result, False)
 
@@ -263,6 +269,16 @@ class UtilTest(unittest.TestCase):
             bot = False
         ))
 
+        result = appier.browser_info("netius/1.1b")
+        self.assertEqual(result, dict(
+            name = "netius",
+            version = "1.1b",
+            version_f = 0,
+            version_i = 0,
+            interactive = False,
+            bot = False
+        ))
+
         result = appier.browser_info("APIs-Google (+https://developers.google.com/webmasters/APIs-Google.html)")
         self.assertEqual(result, None)
 
@@ -903,6 +919,25 @@ class UtilTest(unittest.TestCase):
             lambda: appier.verify_not_equal(1, 1, exception = appier.OperationalError)
         )
 
+    def test_verify_many(self):
+        result = appier.verify_many((1 == 1, 2 == 2, 3 == 3))
+        self.assertEqual(result, None)
+
+        result = appier.verify_many(("hello" == "hello",))
+        self.assertEqual(result, None)
+
+        self.assertRaises(appier.AssertionError, lambda: appier.verify_many((1 == 2,)))
+
+        self.assertRaises(appier.AssertionError, lambda: appier.verify_many((1 == 1, 1 == 2)))
+
+        self.assertRaises(
+            appier.OperationalError,
+            lambda: appier.verify_many(
+                (1 == 1, 1 == 2),
+                exception = appier.OperationalError
+            )
+        )
+
 class FileTupleTest(unittest.TestCase):
 
     def test_basic(self):
