@@ -48,6 +48,7 @@ import locale
 import hashlib
 import calendar
 import datetime
+import warnings
 import functools
 import threading
 import mimetypes
@@ -279,8 +280,10 @@ def browser_info(user_agent):
 
         version_i = user_agent.index(version_search) + len(version_search)
         version = user_agent[version_i:].split(" ", 1)[0].strip(" ;")
-        version_f = float(".".join(version.split(".")[:2]))
-        version_i = int(version_f)
+        try: version_f = float(".".join(version.split(".")[:2]))
+        except ValueError: version_f = 0.0
+        try: version_i = int(version_f)
+        except ValueError: version_f = 0
 
         info.update(
             name = identity,
@@ -1498,7 +1501,7 @@ def check_tokens(self, tokens, tokens_m = None, request = None):
 
 def ensure_login(self, token = None, context = None, request = None):
     request = request or (self.request if self else None)
-    is_auth = "username" in request.session
+    is_auth = "username" in request.session or hasattr(request, "tokens_p")
     if not is_auth: raise exceptions.AppierException(
         message = "User not authenticated",
         code = 403,
@@ -1516,7 +1519,7 @@ def ensure_login(self, token = None, context = None, request = None):
 def get_tokens_m(self, request = None, set = True):
     """
     Retrieves the map of tokens from the current session so that
-    they can be used for proper acl validation.
+    they can be used for proper ACL validation.
 
     In case the current session contains a sequence based representation
     of the tokens they are converted to their equivalent map value.
@@ -1528,17 +1531,26 @@ def get_tokens_m(self, request = None, set = True):
     :param set: If the possible converted tokens list should be persisted
     into the current session.
     :rtype: Dictionary
-    :return: The map of tokens to be used for acl validation.
+    :return: The map of tokens to be used for ACL validation.
     """
 
     # tries to retrieve the request from the current context
-    # in case it has not been passed through other manner
+    # in case it has not been passed through other manner, if
+    # no valid context is found returns invalid value immediately
     request = request or (self.request if self else None)
+    if not request: return dict()
 
-    # tries to retrieve the tokens map from the current session
-    # and then verifies if the resulting value is either a map
-    # or a sequence, going to be used for decisions
-    tokens_m = request.session.get("tokens", {})
+    # tries to retrieve the "provider method "for the tokens under the
+    # current request an in case it's not available used the default
+    # one (simple session access)
+    try:
+        if hasattr(request, "tokens_p"): tokens_m = request.tokens_p()
+        else: tokens_m = request.session.get("tokens", {})
+    except BaseException:
+        return dict()
+
+    # verifies if the resulting value is either a map or a sequence,
+    # going to be used for decisions on normalization
     is_map = isinstance(tokens_m, dict)
     is_sequence = isinstance(tokens_m, (list, tuple))
 
@@ -1651,7 +1663,55 @@ def dict_merge(first, second, override = True, recursive = False):
         final.update(second)
         return final
 
+def deprecated(message = "Function %s is now deprecated"):
+    """
+    Decorator that marks a certain function or method as
+    deprecated so that whenever such function is called
+    an output messaged warns the developer about the
+    deprecation (incentive).
+
+    :type message: String
+    :param message: The message template to be used in the
+    output operation of the error.
+    :rtype: Decorator
+    :return: The decorator that should be used to wrap a
+    function and mark it as deprecated (send warning).
+    """
+
+    def decorator(function):
+
+        name = function.__name__ if hasattr(function, "__name__") else None
+
+        @functools.wraps(function)
+        def interceptor(*args, **kwargs):
+            warnings.simplefilter("always", DeprecationWarning)
+            warnings.warn(
+                message % name,
+                category = DeprecationWarning,
+                stacklevel = 2
+            )
+            warnings.simplefilter("default", DeprecationWarning)
+            return function(*args, **kwargs)
+
+        return interceptor
+
+    return decorator
+
 def cached(function):
+    """
+    Decorator that marks a certain function as cached meaning that
+    the local context of the instance associated with the function
+    (method) is going to be used to store the result and further
+    requests to the function will use the cached result, resulting
+    in an improved resolution time.
+
+    The life-cycle of the context is critical to avoid issues with
+    invalid cache invalidation.
+
+    :rtype: Decorator
+    :return: The decorator that should be used to wrap a function
+    marking it as ready to cache it's return value on current context.
+    """
 
     name = function.__name__
 
@@ -1899,6 +1959,16 @@ def verify_not_equal(first, second, message = None, code = None, exception = Non
         **kwargs
     )
 
+def verify_many(sequence, message = None, code = None, exception = None, **kwargs):
+    for condition in sequence:
+        verify(
+            condition,
+            message = message,
+            code = code,
+            exception = exception,
+            **kwargs
+        )
+
 def execute(args, command = None, path = None, shell = None, encoding = None):
     if shell == None: shell = os.name == "nt"
     if not encoding: encoding = sys.getfilesystemencoding()
